<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="31"/>
        <source>Re&amp;gion:</source>
        <translation>א&amp;זור:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="60"/>
        <source>De&amp;tailed Settings</source>
        <translation>הגדרות מ&amp;פורטות</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="78"/>
        <source>&amp;Numbers:</source>
        <translation>מ&amp;ספרים:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="107"/>
        <source>&amp;Time:</source>
        <translation>&amp;זמן:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="136"/>
        <source>Currenc&amp;y:</source>
        <translation>מ&amp;טבע:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="165"/>
        <source>Measurement &amp;Units:</source>
        <translation>י&amp;חידות מידה:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="194"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>&amp;איסוף ומיון:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="226"/>
        <source>Examples</source>
        <translation>דוגמאות</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>Numbers:</source>
        <translation>מספרים:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="258"/>
        <source>Time:</source>
        <translation>זמן:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="278"/>
        <source>Currency:</source>
        <translation>מטבע:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="298"/>
        <source>Measurement Units:</source>
        <translation>יחידות מידה:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="126"/>
        <source>No change</source>
        <translation>אין שינוי</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="313"/>
        <source>Format Settings Changed</source>
        <translation>הגדרות התבנית השתנו</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="314"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>לשמור את השינויים? הם ייכנסו לתוקף עם הכניסה הבאה.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="417"/>
        <source>Imperial UK</source>
        <translation>אימפריאלית בריטית</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="421"/>
        <source>Imperial US</source>
        <translation>אימפריאלית אמריקאית</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="425"/>
        <source>Metric</source>
        <translation>מטרית</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>הגדרות מקומיות של LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>הגדרות מקומיות</translation>
    </message>
</context>
</TS>
